/* ISC license. */

#include <s6/lock.h>

s6lock_t const s6lock_zero = S6LOCK_ZERO ;
